aboutsummaryrefslogtreecommitdiff
path: root/azalea-world/src/heightmap.rs
diff options
context:
space:
mode:
Diffstat (limited to 'azalea-world/src/heightmap.rs')
-rw-r--r--azalea-world/src/heightmap.rs3
1 files changed, 2 insertions, 1 deletions
diff --git a/azalea-world/src/heightmap.rs b/azalea-world/src/heightmap.rs
index f1ef30d2..00ebad41 100644
--- a/azalea-world/src/heightmap.rs
+++ b/azalea-world/src/heightmap.rs
@@ -1,6 +1,7 @@
use std::{fmt::Display, str::FromStr};
use azalea_block::BlockState;
+use azalea_buf::AzBuf;
use azalea_core::{math, position::ChunkBlockPos};
use azalea_registry::tags::blocks::LEAVES;
@@ -8,7 +9,7 @@ use crate::{BitStorage, Section, chunk_storage::get_block_state_from_sections};
// (wg stands for worldgen)
#[derive(Clone, Copy, Debug, Hash, PartialEq, Eq)]
pub enum HeightmapKind {
WorldSurfaceWg,
WorldSurface,
@@ -8,7 +9,7 @@ use crate::{BitStorage, Section, chunk_storage::get_block_state_from_sections};
// (wg stands for worldgen)
-#[derive(Clone, Copy, Debug, Hash, PartialEq, Eq)]
+#[derive(Clone, Copy, Debug, Hash, PartialEq, Eq, AzBuf)]
pub enum HeightmapKind {
WorldSurfaceWg,